@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ EditorPage::EditorPage(PageType type, QWidget *parent)
 {
 }
 
-EditorPage::~EditorPage()
-{
-}
+EditorPage::~EditorPage() = default;
 
 EditorPage::PageType EditorPage::pageType() const
 {
